@@ -473,11 +473,13 @@ the current state.
 
 =back
 
-=item my ($secs, $nsecs) = $dom->get_time($flags=0);
+=item my $time = $dom->get_time($flags=0);
 
 Get the current time of the guest, in seconds and nanoseconds.
 The C<$flags> parameter is currently unused and defaults to
-zero.
+zero. The return value is an array ref with two elements,
+the first contains the time in seconds, the second contains
+the remaining nanoseconds.
 
 =item $dom->set_time($secs, $nsecs, $flags=0);
 
@@ -1281,7 +1283,7 @@ The expected amount of file remaining to be processed by the job, in bytes.
 
 =back
 
-=item my ($type, $stats) = $dom->get_job_stats()
+=item my ($type, $stats) = $dom->get_job_stats($flags=0)
 
 Returns an array summarising the execution state of the
 background job. The C<$type> value is one of the JOB TYPE
@@ -1296,6 +1298,17 @@ following constants.
 The type of job, one of the JOB TYPE constants listed later in
 this document.
 
+The C<$flags> parameter defaults to zero and can take one of
+the following constants.
+
+=over 4
+
+=item Sys::Virt::Domain::JOB_STATS_COMPLETED
+
+Return the stats of the most recently completed job.
+
+=back
+
 =item Sys::Virt::Domain::JOB_TIME_ELAPSED
 
 The elapsed time in milliseconds
@@ -1342,6 +1355,10 @@ The number of pages transferred without any compression
 
 The number of bytes transferred without any compression
 
+=item Sys::Virt::Domain::JOB_MEMORY_BPS
+
+The bytes per second transferred
+
 =item Sys::Virt::Domain::JOB_DISK_TOTAL
 
 The total amount of file expected to be processed by the job, in bytes.
@@ -1354,6 +1371,10 @@ The current amount of file processed by the job, in bytes.
 
 The expected amount of file remaining to be processed by the job, in bytes.
 
+=item Sys::Virt::Domain::JOB_DISK_BPS
+
+The bytes per second transferred
+
 =item Sys::Virt::Domain::JOB_COMPRESSION_CACHE
 
 The size of the compression cache in bytes
@@ -1381,6 +1402,10 @@ non-compressed page.
 The number of milliseconds of downtime expected during
 migration switchover.
 
+=item Sys::Virt::Domain::JOB_SETUP_TIME
+
+The number of milliseconds of time doing setup of the job
+
 =back
 
 =item $dom->abort_job()
@@ -1391,13 +1416,32 @@ Aborts the currently executing job
 
 Returns a hash reference summarising the execution state of
 the block job. The C<$path> parameter should be the fully
-qualified path of the block device being changed.
+qualified path of the block device being changed. Valid
+C<$flags> include:
+
+=over 4
+
+=item Sys::Virt::Domain::BLOCK_JOB_INFO_BANDWIDTH_BYTES
+
+Treat bandwidth value as bytes instead of MiB.
+
+=back
 
 =item $dom->set_block_job_speed($path, $bandwidth, $flags=0)
 
 Change the maximum I/O bandwidth used by the block job that
 is currently executing for C<$path>. The C<$bandwidth> argument
-is specified in MB/s
+is specified in MB/s.  The C<$flags> parameter
+can take the bitwise union of the values:
+
+=over 4
+
+=item Sys::Virt::Domain::BLOCK_JOB_SPEED_BANDWIDTH_BYTES
+
+The C<$bandwidth> parameter value is measured in bytes/s
+instead of MB/s.
+
+=back
 
 =item $dom->abort_block_job($path, $flags=0)
 
@@ -1408,13 +1452,33 @@ associated with C<$path>
 
 Merge the backing files associated with C<$path> into the
 top level file. The C<$bandwidth> parameter specifies the
-maximum I/O rate to allow in MB/s.
+maximum I/O rate to allow in MB/s. The C<$flags> parameter
+can take the bitwise union of the values:
+
+=over 4
+
+=item Sys::Virt::Domain::BLOCK_PULL_BANDWIDTH_BYTES
+
+The C<$bandwidth> parameter value is measured in bytes/s
+instead of MB/s.
+
+=back
 
 =item $dom->block_rebase($path, $base, $bandwith, $flags=0)
 
 Switch the backing path associated with C<$path> to instead
 use C<$base>. The C<$bandwidth> parameter specifies the
-maximum I/O rate to allow in MB/s.
+maximum I/O rate to allow in MB/s. The C<$flags> parameter
+can take the bitwise union of the values:
+
+=over 4
+
+=item Sys::Virt::Domain::BLOCK_REBASE_BANDWIDTH_BYTES
+
+The C<$bandwidth> parameter value is measured in bytes/s
+instead of MB/s.
+
+=back
 
 =item $dom->block_copy($path, $destxml, $params, $flags=0)
 
@@ -1444,7 +1508,17 @@ The maximum amount of data in flight in bytes.
 Commit changes there were made to the temporary top level file C<$top>.
 Takes all the differences between C<$top> and C<$base> and merge them
 into C<$base>. The C<$bandwidth> parameter specifies the
-maximum I/O rate to allow in MB/s.
+maximum I/O rate to allow in MB/s.  The C<$flags> parameter
+can take the bitwise union of the values:
+
+=over 4
+
+=item Sys::Virt::Domain::BLOCK_COMMIT_BANDWIDTH_BYTES
+
+The C<$bandwidth> parameter value is measured in bytes
+instead of MB/s.
+
+=back
 
 =item $count = $dom->num_of_snapshots()
 
@@ -1554,6 +1628,35 @@ array reference. If <@mountPoints> is an empty list, then all
 filesystems will be thawed. C<$flags> is currently
 unused and defaults to zero.
 
+=item @fslist = $dom->get_fs_info($flags=0);
+
+Obtain a list of all guest filesystems. The returned list will
+contain one element for each filesystem, whose value will be
+a hash reference with the following keys
+
+=over 4
+
+=item name
+
+The name of the guest device that is mounted
+
+=item fstype
+
+The filesystem type (eg 'ext4', 'fat', 'ntfs', etc)
+
+=item mountpoint
+
+The location in the filesystem tree of the mount
+
+=item devalias
+
+An array reference containing list of device aliases
+associated with the guest device. The device aliases
+correspond to disk target names in the guest XML
+configuration
+
+=back
+
 =item $dom->send_process_signal($pid, $signum, $flags=0);
 
 Send the process C<$pid> the signal C<$signum>. The
@@ -1974,6 +2077,10 @@ Abort if an I/O error occurrs on the disk
 Force convergance of the migration operation by
 throttling guest runtime
 
+=item Sys::Virt::Domain::MIGRATE_RDMA_PIN_ALL
+
+Pin memory for RDMA transfer
+
 =back
 
 =head2 UNDEFINE CONSTANTS
@@ -1993,6 +2100,11 @@ domain
 Also remove any snapshot metadata when undefining the virtual
 domain.
 
+=item Sys::Virt::Domain::UNDEFINE_NVRAM
+
+Also remove any NVRAM state file when undefining the virtual
+domain.
+
 =back
 
 =head2 JOB TYPES
@@ -2123,6 +2235,34 @@ The I/O operations read per second.
 
 The I/O operations written per second.
 
+=item Sys::Virt::Domain::BLOCK_IOTUNE_TOTAL_BYTES_SEC_MAX
+
+The maximum total bytes processed per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_READ_BYTES_SEC_MAX
+
+The maximum bytes read per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_WRITE_BYTES_SEC_MAX
+
+The maximum bytes written per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_TOTAL_IOPS_SEC_MAX
+
+The maximum total I/O operations processed per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_READ_IOPS_SEC_MAX
+
+The maximum I/O operations read per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_WRITE_IOPS_SEC_MAX
+
+The maximum I/O operations written per second.
+
+=item Sys::Virt::Domain::BLOCK_IOTUNE_SIZE_IOPS_SEC
+
+The maximum I/O operations per second
+
 =back
 
 =head2 SCHEDULER CONSTANTS
@@ -2540,6 +2680,49 @@ Balloon target changes
 
 Asynchronous guest device removal
 
+=item Sys::Virt::Domain::EVENT_ID_TUNABLE
+
+Changes of any domain tuning parameters. The callback
+will be provided with a hash listing all changed parameters.
+The later DOMAIN TUNABLE constants can be useful when accessing
+the hash keys
+
+=item Sys::Virt::Domain::EVENT_ID_AGENT_LIFECYCLE
+
+Domain guest agent lifecycle events. The C<state> parameter
+to the callback will match one of the constants
+
+=over 4
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_STATE_CONNECTED
+
+The agent is now connected
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_STATE_DISCONNECTED
+
+The agent is now disconnected
+
+=back
+
+The second parameter, C<reason>, matches one of the following
+constants
+
+=over 4
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_REASON_UNKNOWN
+
+The reason is unknown
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_REASON_DOMAIN_STARTED
+
+The domain was initially booted
+
+=item Sys::Virt::Domain::EVENT_AGENT_LIFECYCLE_REASON_CHANNEL
+
+The channel on a running guest changed state
+
+=back
+
 =back
 
 =head2 IO ERROR EVENT CONSTANTS
@@ -2744,6 +2927,10 @@ Make destination file raw
 
 Start a copy job
 
+=item Sys::Virt::Domain::BLOCK_REBASE_COPY_DEV
+
+Treat destination as a block device instead of file
+
 =item Sys::Virt::Domain::BLOCK_REBASE_RELATIVE
 
 Keep backing chain referenced using relative names
@@ -3195,39 +3382,39 @@ bulk domain stats from C<Sys::Virt::get_all_domain_stats>.
 
 =over 4
 
-=item Sys::Virt::GET_ALL_STATS_ACTIVE
+=item Sys::Virt::Domain::GET_ALL_STATS_ACTIVE
 
 Include stats for active domains
 
-=item Sys::Virt::GET_ALL_STATS_INACTIVE
+=item Sys::Virt::Domain::GET_ALL_STATS_INACTIVE
 
 Include stats for inactive domains
 
-=item Sys::Virt::GET_ALL_STATS_OTHER
+=item Sys::Virt::Domain::GET_ALL_STATS_OTHER
 
 Include stats for other domains
 
-=item Sys::Virt::GET_ALL_STATS_PAUSED
+=item Sys::Virt::Domain::GET_ALL_STATS_PAUSED
 
 Include stats for paused domains
 
-=item Sys::Virt::GET_ALL_STATS_PERSISTENT
+=item Sys::Virt::Domain::GET_ALL_STATS_PERSISTENT
 
 Include stats for persistent domains
 
-=item Sys::Virt::GET_ALL_STATS_RUNNING
+=item Sys::Virt::Domain::GET_ALL_STATS_RUNNING
 
 Include stats for running domains
 
-=item Sys::Virt::GET_ALL_STATS_SHUTOFF
+=item Sys::Virt::Domain::GET_ALL_STATS_SHUTOFF
 
 Include stats for shutoff domains
 
-=item Sys::Virt::GET_ALL_STATS_TRANSIENT
+=item Sys::Virt::Domain::GET_ALL_STATS_TRANSIENT
 
 Include stats for transient domains
 
-=item Sys::Virt::GET_ALL_STATS_ENFORCE_STATS
+=item Sys::Virt::Domain::GET_ALL_STATS_ENFORCE_STATS
 
 Require that all requested stats fields are returned
 
@@ -3240,10 +3427,30 @@ are returned for stats queries.
 
 =over
 
+=item Sys::Virt::Domain::STATS_BALLOON
+
+Balloon statistics
+
+=item Sys::Virt::Domain::STATS_BLOCK
+
+Block device info
+
+=item Sys::Virt::Domain::STATS_CPU_TOTAL
+
+CPU usage info
+
+=item Sys::Virt::Domain::STATS_INTERFACE
+
+Network interface info
+
 =item Sys::Virt::Domain::STATS_STATE
 
 General lifecycle state
 
+=item Sys::Virt::Domain::STATS_VCPU
+
+Virtual CPU info
+
 =back
 
 =head2 PROCESS SIGNALS
@@ -3516,6 +3723,99 @@ SIGRT32
 
 =back
 
+=head2 DOMAIN TUNABLE CONSTANTS
+
+The following constants are useful when accessing domain
+tuning parameters in APIs and events
+
+=over 4
+
+=item Sys::Virt::Domain::TUNABLE_CPU_CPU_SHARES
+
+Proportional CPU weight
+
+=item Sys::Virt::Domain::TUNABLE_CPU_EMULATORPIN
+
+Emulator thread CPU pinning mask
+
+=item Sys::Virt::Domain::TUNABLE_CPU_EMULATOR_PERIOD
+
+Emulator thread CPU period
+
+=item Sys::Virt::Domain::TUNABLE_CPU_EMULATOR_QUOTA
+
+Emulator thread CPU quota
+
+=item Sys::Virt::Domain::TUNABLE_CPU_VCPUPIN
+
+VCPU thread pinning mask
+
+=item Sys::Virt::Domain::TUNABLE_CPU_VCPU_PERIOD
+
+VCPU thread period
+
+=item Sys::Virt::Domain::TUNABLE_CPU_VCPU_QUOTA
+
+VCPU thread quota
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_DISK
+
+The name of guest disks
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_READ_BYTES_SEC
+
+Read throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_READ_IOPS_SEC
+
+Read throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_TOTAL_BYTES_SEC
+
+Total throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_TOTAL_IOPS_SEC
+
+Total throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_WRITE_BYTES_SEC
+
+Write throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_WRITE_IOPS_SEC
+
+Write throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_READ_BYTES_SEC_MAX
+
+Maximum read throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_READ_IOPS_SEC_MAX
+
+Maximum read throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_TOTAL_BYTES_SEC_MAX
+
+Maximum total throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_TOTAL_IOPS_SEC_MAX
+
+Maximum total throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_WRITE_BYTES_SEC_MAX
+
+Maximum write throughput in bytes per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_WRITE_IOPS_SEC_MAX
+
+Maximum write throughput in I/O operations per sec
+
+=item Sys::Virt::Domain::TUNABLE_BLKDEV_SIZE_IOPS_SEC
+
+The maximum I/O operations per second
+
+=back
+
 =head1 AUTHORS
 
 Daniel P. Berrange <berrange@redhat.com>
